#
# spec file for package corebird
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2013-2014 Dominique Leuenberger, Amsterdam, The Netherlands.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           corebird
Version:        1.7.4
Release:        lp150.1.3
Summary:        A lightweight Twitter Client
License:        GPL-3.0+
Group:          Productivity/Networking/Other
Url:            http://corebird.baedert.org/
Source:         https://github.com/baedert/%{name}/releases/download/%{version}/%{name}-%{version}.tar.xz
BuildRequires:  gettext >= 0.19.7
BuildRequires:  intltool
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  vala-devel >= 0.28.0
BuildRequires:  pkgconfig(gdk-x11-3.0)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0) >= 2.44
BuildRequires:  pkgconfig(gspell-1)
BuildRequires:  pkgconfig(gstreamer-video-1.0) >= 1.6
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.20
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(libsoup-2.4)
BuildRequires:  pkgconfig(sqlite3)
Recommends:     %{name}-lang

%description
Native Twitter client, integrating into GNOME 3.

%lang_package

%prep
%setup -q

%build
%configure
make %{?_smp_mflags}

%install
%make_install
%suse_update_desktop_file org.baedert.corebird X-SuSE-Core-Internet
%find_lang %{name} %{?no_lang_C}

%if 0%{?suse_version} < 1330
%post
%glib2_gsettings_schema_post
%icon_theme_cache_post
%desktop_database_post

%postun
%glib2_gsettings_schema_postun
%icon_theme_cache_postun
%desktop_database_postun
%endif

%files
%doc COPYING
%{_bindir}/%{name}
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/org.baedert.corebird.appdata.xml
%{_datadir}/applications/org.baedert.corebird.desktop
%{_datadir}/dbus-1/services/org.baedert.corebird.service
%{_datadir}/glib-2.0/schemas/org.baedert.corebird.gschema.xml
%{_datadir}/icons/hicolor/
%{_mandir}/man1/%{name}.1%{?ext_man}

%files lang -f %{name}.lang

%changelog
* Sat Mar 10 2018 bjorn.lie@gmail.com
- Update to version 1.7.4:
  + Fix tweet sending on 32bit architectures.
  + Fix a few spelling mistakes.
  + Work around a GTK+ bug increasing the window size when typing
    DMs.
  + Prevent the list statuses page from automatically focusing the
    delete button, potentially resulting in accidentally deleted
    lists.
  + Show a language selection context menu in the compose text
    view.
* Sun Nov 19 2017 aavindraa@gmail.com
- Update to version 1.7.3:
  + Increase maximum tweet length to 280 characters
  + Increase maximum name length to 50 characters and improve
    certain parts of the UI to cope better with longer names
  + Fix the emoji button not showing up in the compose window
  + Update translations
* Sat Nov  4 2017 aavindraa@gmail.com
- Update to version 1.7.2:
  + Fix window cancel button label mixup
  + Fix potential crash when composing a tweet
  + Fix abort when trying to detect emoji support
  + Fix spell checking
  + Update translations
* Sat Oct 28 2017 aavindraa@gmail.com
- Update to version 1.7.1:
  + Fixed a small problem with the appdata file in 1.7.
- Changes from version 1.7:
  + Hashtags and Mentions in profile desriptions are now clickable.
  + The mention-completion when composing a new tweet now fetches
    unknown users from the twitter server.
  + Videos larger than the screen size are now getting scaled down
    while playing.
  + Profiles now indicate when an account is suspended.
  + Profiles handle protected accounts better when trying to
    access followers/following users, etc..
  + The compose window now allows tweets with just media
    attached but not text.
  + Improve the hashtag/mention/link detection when composing a new
    tweet.
  + The compose dialog now shows an emoji chooser. This is
    only available starting GTK+ 3.22.19 and the emojis will only
    be rendered with color if you have the needed cairo version
    installed, as well as an emoji font.
  + Fixed a bug that led to wrong Direct Message info being
    inserted into the database.
  + Fixed a bug that resulted in broken files when downloading
    instagram images.
- Added explicit pkgconfig BuildRequires (change by spec-cleaner).
* Sun Sep 24 2017 aavindraa@gmail.com
- Update to version 1.6
  + Dependencies: GTK+ 3.20 is now required, and librest is no longer
    a dependency.
  + Facelift for the tweet info page.
  + Lots of stability fixes.
  + The compose window now starts uploading images as soon as they
    are selected.
- Only use post scripts for schema, desktop, and icon cache handling
  on suse_version < 1330.
- Drop pkgconfig(rest-0.7) BuildRequries: no longer needed.
* Tue Jul 11 2017 zaitor@opensuse.org
- Update to version 1.5.1 (boo#1048021):
  + Stability improvements.
- Changes from version 1.5.0:
  + Media attached to tweets can be downloaded using Right Click
    and selecting "save as".
  + Profiles use the profile background color set in the Twitter
    settings if no banner is set.
  + The tweet compose window now features a "favorite image" view
    that allows users to save often sent images and quickly add
    them to tweets.
  + The media dialog now shows Previous/Next buttons to quickly
    switch between multiple media attachments of a tweet>.
  + The Vine support has been removed since the project is
    discontinued.
  + Allow text selection in Direct Messages.
  + New --account parameter allows opening the window for the given
    account only.
  + Support tweets with up to 50 replied-to users.
  + Add back verified icons next to user avatars.
  + Redesigned account creation UI.
  + Tons of bug fixes.
- Drop a no longer needed libtool BuildRequires, the patch that
  needed it was dropped a long time ago.
- Add explicit gettext BuildRequires and version it.
* Mon Feb  6 2017 zaitor@opensuse.org
- Update to version 1.4.2:
  + Fix a crash when going back from a tweet with media to another
    tweet with media.
  + Fix compilation with --disable-video.
  + Decrease log level of UserStream output to debug when no
    internet connection is present.
- Changes from version 1.4.1:
  + Lower the required gspell version to 1.0.
  + Work around a binding problem in the gtk+ 3.18 vapi of vala
    0.30.
- Changes from version 1.4:
  + Images in quoted tweets now look more like they actually belong
    to the quoted tweet instead of the quoting tweet.
  + Allow deleting tweets from the tweet info page and not just
    from timelines.
  + Fix the user completion not showing all possible results.
  + Focus the already opened window for an account if the account
    gets selected in the accounts popover.
  + Avoid window resizing when typing in the Direct Message text
    box.
  + Add 'q' accelerator to tweet rows for quoting.
  + Add spellchecking. This add a dependency to gspell.
  + Increase gtk+ dependency to 3.18 to get rid of some
    workarounds.
  + Increase avatar size in profiles and slightly overlap them over
    the banner. Also, always show the full banner.
  + Fix completion popup positioning under Wayland.
  + Add experimental meson build files.
  + Fix some videos not playing correctly.
  + Add a minimal video progress indicator to the video dialog.
  + Fix the retweet/favorite count updating in the tweet info page.
- Add pkgconfig(gspell-1) BuildRequires: New dependency.
* Wed Nov  2 2016 dimstar@opensuse.org
- Update to version 1.3.3:
  + Support longer tweets in a few more places.
  + Properly escape ampersand characters in user mentions to fix
    GtkLabel warnings about wrong escape characters in tooltips.
  + Fix tweet length calculations for whitespace-only tweets.
  + Check for duplicated entries in media arrays. This is
    apparently a problem on Twitter's side but led to crashes in
    Corebird (gh#baedert/corebird#627).
  + Use the correct nsfw status of a tweet, i.e. the one that can
    actually show images.
  + Fix a crash when sending a tweet with multiple images attached.
  + Fix tweet length calculation of quote tweets. This previously
    led to tweets getting rejected by the server even though
    Corebird claimed they were fine (gh#baedert/corebird#628).
- Changes from version 1.3.2:
  + Cope with the tweet length changes introduced by Twitter.
  + Fix a problem with malformed media URLs.
- Changes from version 1.3.1:
  + Fix muted and/or blocked tweets still showing up in timelines.
  + Fix accounts not getting saved when first created.
  + Fix retweets of the authenticating user not getting their
    correct seen status.
  + Fix profiles descriptions containing ampersand characters and
    links.
  + Fix profile banner fade-in transition.
  + Fix doubly-escaped ampersands in link tooltips.
  + Fix missing underlines in @screen_names in the profile popover.
- Changes from version 1.3.0:
  + The build system will now check for gtksink.
  + Remove libgee dependency.
  + The compose tweet window will now a save the current text on
    cancel.
  + Allow self-retweeting.
  + Fade loaded inline media in.
  + Twitter wont send mp4 urls for their videos anymore starting
    August 1st, so support HLS videos.
  + Query full-length DMs.
  + Support muting in profiles.
- Drop pkgconfig(gee-0.8) BuildRequires: no longer needed.
- No longer call autogen.sh: the tarball is bootstrapped.
* Fri Jun 24 2016 zaitor@opensuse.org
- Update to version 1.2.2:
  + Remove margins from the buttons in the topbar. This caused
    problems with some gtk+ themes.
  + Gtk+ < 3.20 was more inconsistend with adding style classes to
    widgets than I thought, so the pre-3.20 fallback css added in
    1.2.1 caused the icons in the topbar to have the wrong color.
- Changes from version 1.2.1:
  + Fix a11y labelling of several switches in the settings dialog.
  + Fix an input window clipping bug in the tweet info page.
  + Fix a few cases of overlapping widgets into window borders.
  + Remove the "Save as" context menu from inline media. This have
    not been working in a while but the context menu was still
    there.
  + Rename the .sidebar style class to .topbar. This was used in
    corebird before gtk+ used it, but now that the sidebar is at
    the top, the .sidebar style from gtk+ themes collides with the
    horizontal alignment we use, so use the more fitting '.topbar'.
  + Show a focus outline in the topbar again. We are setting a
    custom background color here, so we also need to set a fitting
    outline color.
  + Fix a coloring but in the topbar, where wildcard selectors in
    themes would overrde our foreground color.
- Changes from version 1.2:
  + Inline media and avatars are no longer cached on disk.
  + Videos now indicate download progress showing a preview
    thumbnail with a circular progress overlay.
  + We download higher-resolution avatars on HiDPI displays now.
  + The build system usage has seen a major refactoring an cleanup.
  + The sidebar is now at the top and dark.
  + Favorites now us a heart icon.
  + Sending tweets is now cancellable (e.g. when multiple images
    are attached, in which case it might take a while).
  + Inline media are now displayed "full-size", scaled to the
    current window size.
  + Instagram videos are now correctly marked as videos, instead
    of was images.
  + If you have GTK+ >= 3.19, there's now a GtkShortcutsWindow
    accessible from the app menuexplaining the various keyboard
    shortcuts. Note that Corebird still compiles and runs with
    GTK+ 3.16.
  + The big "add media" button in the compose window has been
    replaced with a regular text button. The added images are
    scaled down and displayed below it.
  + You can quote your own tweets now.
  + The settings dialog now contains a setting to hide
    "inappropriate content", and it is enabled by default.
  + The file selection dialog in the compose window now keeps
    you from selecting files > 3MB.
- The about dialog still states version 1.2.1, this is a known bug.
* Thu Oct 22 2015 lmouillart@gmail.com
- Update to version 1.1:
  + The behavior in corebird on how tweets get hidden and shown
    is now more consistent.
  + Corebird now provides snippets that you are used to insert
    common phrases or emoticons. Simply type the keyword for the
    snippet, and press tab to autocomplete. Settings for adding and
    configuring snippets is found in the application settings in
    the “Snippets” tab.
  + Corebird now supports showing Twitter quote tweets in timelines
    as well as creating quote tweets. This replaces the old “Quote”
    item for tweets which would simply copy the original
    tweet’s text.
  + Twitter removed the 140 char limit on Direct Messages,
    so this limit is also removed in Corebird.
* Mon Aug  3 2015 lmouillart@gmail.com
- Update to version 1.0.1:
  + Fix show-window action parameter.
  + Fix load lists.
  + Fix black screen instead of playback with 1.0.
* Sat Jun 20 2015 lmouillart@gmail.com
- Update to version 1.0:
  + All dialogs now use client-side decorations if the environment
    dictates it, otherwise they fall back to server-side
    decorations (compose dialog is excluded).
  + Many layout updates
  + The compose window now allows for up to 4 pictures to be
    uploaded.
  + Now save additional information about the account which makes
    it possible for blocked users to be actually blocked,
    i.e. streamed tweets won’t appear in your timeline anymore.
  + When (un)following someone, now also correctly show/hide
    their retweets in the stream.
  + The DM page now sorts threads with unread messages first.
  + The @handle completion known from the compose window is
    now also available when composing Direct Messages,
    as well as in the account settings for the description.
  + Everything app-specific should now be hidpi ready,
    the only thing missing are assets loaded from Twitter
    directly, i.e. avatars and media.
  + Notifications should now get withdrawn whenever it makes sense,
    i.e. if you read a Direct Message before dismissing the
    notification, it should get withdrawn automatically.
  + The hover buttons moved to a right-click menu on every tweet.
  + Plurals are properly localized.
  + We now also respect muted users (even though there’s no UI to
    mute someone)
  + A user’s verification status is now also shown in the tweet
    info page.
  + Everything should now work when the user’s @handle
    (aka screen_name) changes.
  + Switching to the same page (i.e. going to a profile from the
    profile page) now works much better, including the swipe
    transition as well as proper equality checking.
  + Invalid inline media (file size too big, 404, …) should now
    be properly detected and reacted upon (i.e. remove the widget
    in the stream, add the link back).
  + Underlines in @handles are now properly displayed in the app
    menu (i.e. the “open account” submenu)
  + Animated gifs from Twitter are now also handled (just like
    other videos).
  + Tweets in timelines are now single-click activated. This
    unifies the behavior with all other lists in the application.
    Since this interferes with certain user behaviors, there’s a
    setting to switch back to double-click activation.
  + Based on a user’s protection status, we now disable (or hide)
    retweet buttons of tweets.
* Wed Dec 24 2014 zaitor@opensuse.org
- Update to version 0.9:
  + Mentions, hashtags and links now get highlighted directly in
    the compose window.
  + The avatar of the currently active account in a window is now
    clickable, showing all configured accounts.
  + The logic for autostarting accounts is more explicit now.
  + The setting regarding the dark theme is gone (existing
    configurations will keep working).
  + When viewing an image of a tweet with multiple images/videos
    attached, you can now use the cursor keys to navigate between
    them.
  + Avatars in tweets and profiles now show if the user is
    verified.
  + Lots of the application should now react better to missing
    network connections.
  + The activity indicator for loading older tweets is now in the
    tweet list itself.
  + Some things now get immediately applied instead of needing a
    restart of the client.
  + Each window now has a back button, additionally to all the
    keyboard shortcuts available for going back and forward.
  + Last but not least, large parts of the UI have been refined,
    spacing, icons, etc. have been changed.
- Drop corebird-fix-binding-usage.patch and
  corebird-fix-manpage-install.patch: Fixed upstream.
* Mon Sep  8 2014 dimstar@opensuse.org
- Update to version 0.8:
  + Switch build system from cmake to automake.
  + Internal code reorganisation.
  + Add test units.
  + Updated translations.
- Enable make check in %%check section.
- Replace cmake call with autogen.sh (tarball is not bootstrapped)
  and configure.
- Add libtool BuildRequires: needed in order to run autogen.sh.
- Drop cmake BuildRequires: no longer needed after the switch to
  automake.
- Add pkgconfig(gstreamer-video-1.0) and pkgconfig(gdk-x11-3.0)
  BuildRequires: new dependencies.
- Add corebird-fix-binding-usage.patch: Fix usage of bindings.
- Add corebird-fix-manpage-install.patch: Fix man page
  installation.
* Wed Apr 30 2014 malcolmlewis@opensuse.org
- Updated to version 0.7:
  + Regex-based filters are implemented, i.e. you can hide tweets
    you don't want to see.
  + With the introduction of filters, individual users can now also
    be blocked.
  + Replying to tweets now correctly mentions all the users
    mentioned in the original tweet.
  + There's now a favorite timeline, showing all the tweets you
    have favorited.
  + The compose window now completes user names whenever the user
    writes an @.
  + Open windows are now correctly saved on application quit.
  + Tons of refactoring to ensure future progress.
  + Fixed Bugs:
  * #99 - Reorganize the settings dialog.
  * #93 - Feature Request: Add UI for starred tweets.
  * #102 - Remember location of the settings dialog.
  * #107 - Clicking the name link on a "retweeted by" tweet does
    nothing.
  * #108 - Corebird needs a Manpage.
  * #105 - corebird segfaults when using newer versions of glib2
    (2.39.2).
  * #103 - Unfaving a favourited tweet in the favourited list
    disables the tweet.
  * #97 - Reply to all.
  * #117 - Following someone turns on mobile notifications.
  * #126 - Links in DM preview texts are wrong.
  * #4 - How to translate it into other language, such as zh_CN.
  * #41 - Add posibility to mute some content.
  * #56 - Tab Completion for Users and Hashtags.
  + Updated translations.
* Thu Feb  6 2014 malcolmlewis@opensuse.org
- Updated to version 0.6.1:
  + Always show the settings dialog on startup if no startup
    accounts are set. Previously, this broke the very first start
    where org.baedert.corebird.startup-account either contained
    only one empty item or no item at all.
- Changes from version 0.6.0:
  + Support for Twitter Lists added.
  + Updated icons.
  + The last tweet that was selected in a list of tweets (e.g. the
    Main timeline or Replies) is now remembered when switching back
    and forth between pages.
  + The user can now set the maximum inline media size by
    Megabytes.
  + The Corebird sidebar can now be hidden.
  + The keyboard shortcuts for hiding/showing the toolbar, and
    composing a new tweet are now stored in GNOME gsettings.
  + Buttons are now aligned at the top of a tweet and will not
    obscure the tweet.
  + Shortcuts have been changed to require a double press of the
    key.
  + The User Profiles page now displays if the user is following
    you.
  + The User Profiles page now displays if the user is a verified
    user on twitter.
  + The position of corebird main windows is now persistent.
  + Accessibility in corebird is now improved. Notable improvements
    include fixes for uses utilizing screen readers. Special thanks
    to Peter Vágner for contributing these improvements.
  + Many other bugfixes and enhancements.
* Mon Dec 23 2013 dimstar@opensuse.org
- Initial package, version 0.5.
